/*
 * motor.c
 *
 *  Created on: 13.05.2015
 *  Author: Ferdinand Goss, Julius Imbery, Markus Steimle
 */

#include "motor.h"
#include <system.h>

/****************************************************************************
  Function:
    void setSteering(int anglePos)

  Description:
    This function sets the steering of the vehicle

  Precondition:
    None

  Parameters:
    int anglePos - Steering angle from -7 till 7 

  Returns:
    None

  Remarks:
    anglePos = 0 means straight
	anglePos = -7 means complete right 
	anglePos = 7 means complete left
  ***************************************************************************/
void setSteering(int anglePos) 
{
	unsigned long period = 20000;


	float values_1[15] = { 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 25.8, 38.0, 50.1, 63.5, 76.0, 88.2 };
	float values_2[15] = { 88.2, 76.0, 63.5, 50.1, 38.0, 25.8, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0 };

	float servo_duty1 = 20000 * 0.01 * values_1[anglePos+7];
	float servo_duty2 = 20000 * 0.01 * values_2[anglePos+7];


	motor_setting_servo(0, (unsigned long)servo_duty1, 0, (unsigned long)servo_duty2, period, 3);

}

/****************************************************************************
  Function:
    void motor_setting_servo(unsigned long phase1, unsigned long duty1,
			unsigned long phase2, unsigned long duty2, unsigned long period,unsigned long enable)

  Description:
    This function sets the values for the PWM to set the servo motor

  Precondition:
    None

  Parameters:
	unsigned long phase1 - Phase 1
	unsigned long duty1  - Duty 1
	unsigned long phase2 - Phase 2
	unsigned long duty2  - Duty 2
	unsigned long period - Period
	unsigned long enable - Enable

  Returns:
    None

  Remarks:
	This function is called by setSteering(int anglePos) 
 **************************************************************************/
void motor_setting_servo(unsigned long phase1, unsigned long duty1,unsigned long phase2, unsigned long duty2,
		unsigned long period,unsigned long enable)
{
	unsigned long * pwm_en= (unsigned long *)PWM2_EN;
	unsigned long * pwm_period=(unsigned long *)PWM2_PERIOD;
	unsigned long * pwm_phase1=(unsigned long *)PWM2_PHASE1;
	unsigned long * pwm_phase2=(unsigned long *)PWM2_PHASE2;
	unsigned long * pwm_duty1=(unsigned long *)PWM2_DUTY1;
	unsigned long * pwm_duty2=(unsigned long *)PWM2_DUTY2;

	* pwm_en=enable;
	* pwm_period=period;
	* pwm_phase1=phase1;
	* pwm_phase2=phase2;
	* pwm_duty1=duty1;
	* pwm_duty2=duty2;

}


/****************************************************************************
  Function:
    void setSpeedPerc(short percentage)

  Description:
    This function sets the speed of the vehicle

  Precondition:
    None

  Parameters:
    short percentage - speed from 0% till 100%

  Returns:
    None

  Remarks:
    None
  ***************************************************************************/
void setSpeedPerc(short percentage) 
{
	unsigned long temp_duty2 = 0; 
	unsigned long temp_duty1 = 0;
	unsigned long enable = 0;

	if (percentage > 100)
	{
		percentage = 100;
	}
	else if (percentage < -100)
	{
		percentage = -100;
	}

	if (percentage > 0)
	{
		enable = 1;
		temp_duty1 = percentage*100;
		temp_duty2 = 0;
	}
	else
	{
		enable = 2;
		temp_duty1 = 0;
		temp_duty2 = -1*percentage*100;
	}

	unsigned long phase1 = 0x000, phase2 = 0x000, period = 10000;

	tractionMotorSetting(phase1, temp_duty1, phase2, temp_duty2, period, enable);
}


/****************************************************************************
  Function:
    void tractionMotorSetting(unsigned long phase1, unsigned long duty1,
			unsigned long phase2, unsigned long duty2, unsigned long period,unsigned long enable)

  Description:
    This function sets the values for the PWM to set the vehicle speed

  Precondition:
    None

  Parameters:
	unsigned long phase1 - Phase 1
	unsigned long duty1  - Duty 1
	unsigned long phase2 - Phase 2
	unsigned long duty2  - Duty 2
	unsigned long period - Period
	unsigned long enable - Enable

  Returns:
    None

  Remarks:
	This function is called by setSpeedPerc(short percentage)
 **************************************************************************/
void tractionMotorSetting(unsigned long phase1, unsigned long duty1,
		unsigned long phase2, unsigned long duty2, unsigned long period,
		unsigned long enable)
{
	volatile unsigned int * pwm_en = (volatile unsigned int *) PWM0_EN;
	volatile unsigned int * pwm_period = (volatile unsigned int *) PWM0_PERIOD;
	volatile unsigned int * pwm_phase1 = (volatile unsigned int *) PWM0_PHASE1;
	volatile unsigned int * pwm_phase2 = (volatile unsigned int *) PWM0_PHASE2;
	volatile unsigned int * pwm_duty1 = (volatile unsigned int *) PWM0_DUTY1;
	volatile unsigned int * pwm_duty2 = (volatile unsigned int *) PWM0_DUTY2;

	*pwm_en = enable;
	*pwm_period = period;
	*pwm_phase1 = phase1;
	*pwm_phase2 = phase2;
	*pwm_duty1 = duty1;
	*pwm_duty2 = duty2;

}


